#include <cstdio>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <utility>
#include <climits>

using namespace std;

const int MAXN = 100 * 1000;

#define next gnil
#define prev aloe

int next[MAXN];
int prev[MAXN];
bool dead[MAXN];
int n, m;

long long up(long long a, long long b) {
    return (a + b - 1) / b;
}

int dist(int a, int b) {
    return (b - a + m) % m;
}

bool isBetween(int a, int b, int c) {
    return ((a <= c && c <= b) || (a > b && (c <= b || a <= c)));
}

vector <int> startPositions;
vector <int> jump;
pair<long long, int> currentTime(0, 0);

int position(int index, long long first, int second) {
    return (1ll * startPositions[index] + 1ll * jump[index] * (first % m + (index <= second)) % m) % m;
}

pair<long long, int> feedingTime(int index) {
    if (index < next[index] && jump[index] == m) {
        return make_pair(0, index);
    }
    if (index < next[index] && isBetween(startPositions[index], (startPositions[index] + jump[index]) % m, startPositions[next[index]])) {
        return make_pair(0, index);
    }
    if (jump[index] > jump[next[index]]) {
        if (index < next[index]) {
            return make_pair(up(dist((startPositions[index] + jump[index]), startPositions[next[index]]), jump[index] - jump[next[index]]), index);
        }
        return make_pair(up(dist(startPositions[index], startPositions[next[index]]), jump[index] - jump[next[index]]) - 1, index);
    }
    
    return make_pair(LLONG_MAX, INT_MAX);
}

int main() {
    scanf("%d %d", &n, &m);
    vector <pair<int, int> > pos(n);
    startPositions.resize(n);
    jump.resize(n);
    for (int i = 0; i < n; ++i) {
        pos[i].second = i;
        scanf("%d %d", &pos[i].first, &jump[i]);
        --pos[i].first;
        startPositions[i] = pos[i].first;
    }
    sort(pos.begin(), pos.end());
    set<pair<long long, int> > eventTime;
    for (int i = 0; i < n; ++i) {
        next[pos[i].second] = pos[(i + 1) % n].second;
        prev[next[pos[i].second]] = pos[i].second;
        eventTime.insert(feedingTime(pos[i].second));
    }
    int cnt = n;
    while (eventTime.size()) {
        currentTime = *eventTime.begin();
//         printf("%lld %d\n", currentTime.first, currentTime.second);
        if (currentTime.first == LLONG_MAX) {
            eventTime.clear();
            break;
        }
        eventTime.erase(eventTime.begin());
        int i = currentTime.second;
        if (dead[i]) {
            continue;
        }
        if (jump[i] == m) {
            printf("1\n");
            printf("%d\n", i + 1);
            return 0;
        }
        int startPosition = position(i, currentTime.first, currentTime.second - 1), endPosition = position(i, currentTime.first, currentTime.second);
        int eaten = 0;
        while (isBetween(startPosition, endPosition, position(next[i], currentTime.first, currentTime.second))) {
            if (next[i] == i) {
                eventTime.clear();
                break;
            }
            if (!dead[next[i]]) {
                ++eaten;
                --cnt;
            }
            dead[next[i]] = true;
            while (dead[next[i]]) {
                next[i] = next[next[i]];
                prev[next[i]] = i;
            }
        }
        
        eventTime.erase(feedingTime(prev[i]));
        startPositions[i] = (1ll * startPositions[i] + 1ll * jump[i] * (currentTime.first + 1)) % m;
        jump[i] = max(jump[i] - eaten, 0);
        startPositions[i] = (1ll * startPositions[i] - 1ll * jump[i] * (currentTime.first + 1) % m + m) % m;
        
        eventTime.insert(feedingTime(i));
        if (prev[i] != i) {
            eventTime.insert(feedingTime(prev[i]));
        }
        
    }
    printf("%d\n", cnt);
    for (int i = 0; i < n; ++i) {
        if (!dead[i]) {
            printf("%d ", i + 1);
        }
    }
    printf("\n");
    return 0;
}
