#include <algorithm>
#include <cstdio>
#include <ctime>
#include <set>
#include <vector>

using namespace std;

struct Frog {
    int num, pos, jump;
    bool alive;
    
    Frog() : alive(true) {}
};

int clean_path(int const num, int left, int right, set<pair<int, int> > &poses, vector<Frog> &frogs) {
    int cnt = 0;
    
    while (true) {
        set<pair<int, int> >::const_iterator it = poses.lower_bound(make_pair(left, 0));
        if (it == poses.end() || (it->first > right || num == frogs[it->second].num)) {
            return cnt;
        }
        
        ++cnt;
        frogs[it->second].alive = false;
        left = it->first;
        poses.erase(it);
    }
}

int main() {
    clock_t start = clock();
    
    int n, m;
    scanf("%d %d", &n, &m);
    
    set<pair<int, int> > frog_poses;
    vector<Frog> frogs(n);
    vector<int> curr(n);
    
    for (int i = 0; i != n; ++i) {
        scanf("%d %d", &frogs[i].pos, &frogs[i].jump);
        --frogs[i].pos;
        
        curr[i] = i;
        frogs[i].num = i;
        frog_poses.insert(make_pair(frogs[i].pos, i));
    }
    
    int iter_num = 0;
    vector<int> next;
    
    while (true) {
        bool to_next = false;
        
        for (int i = 0; i != (int)curr.size(); ++i) {
            Frog &frog = frogs[curr[i]];
            
            if (!frog.alive) {
                if (!to_next) {
                    next.insert(next.begin(), curr.begin(), curr.begin() + i);
                    to_next = true;
                }
                continue;
            } else if (to_next) {
                next.push_back(curr[i]);
            }
            
            if (!frog.jump) continue;
            int finish = (frog.pos + frog.jump) % m, killed;
            
            if (finish > frog.pos) {
                killed = clean_path(curr[i], frog.pos + 1, finish, frog_poses, frogs);
            } else {
                killed = clean_path(curr[i], frog.pos + 1, m - 1, frog_poses, frogs);
                killed += clean_path(curr[i], 0, finish, frog_poses, frogs);
            }
            
            frog_poses.erase(make_pair(frog.pos, curr[i]));
            frog.pos = finish;
            frog_poses.insert(make_pair(frog.pos, curr[i]));
            frog.jump = max(frog.jump - killed, 0);
        }
        
        if (!next.empty()) {
            curr.swap(next);
            next.clear();
        }
        
        if (iter_num == 10000) {
            if ((double)(clock() - start) / CLOCKS_PER_SEC > 1.9) {
                break;
            }
            iter_num = 0;
        }
        ++iter_num;
    }
    
    printf("%d\n", (int)curr.size());
    for (int i = 0; i != curr.size(); ++i) {
        printf("%d ", curr[i] + 1);
    }
    
    return 0;
}
