#include <algorithm>
#include <cstdio>
#include <ctime>
#include <vector>

using namespace std;

int m;

struct Frog;
struct BidirectedNode;

struct Frog {
    int num, pos, jump;
    bool alive;
    BidirectedNode *node;
    
    Frog() : alive(true) {}
};

struct BidirectedNode {
    BidirectedNode *left, *right;
    Frog &frog;
    
    BidirectedNode (Frog & frog) : frog(frog), left(this), right(this) {
        frog.node = this;
    }
    
    ~BidirectedNode() {
        left->right = right;
        right->left = left;
    }
    
    BidirectedNode * insert_right(Frog &next_frog) {
        BidirectedNode *curr = new BidirectedNode(next_frog);
        right->left = curr;
        curr->right = right;
        curr->left = this;
        right = curr;
        return curr;
    }
};

vector<BidirectedNode *> build_list(vector<Frog> &frogs, vector<int> const &sorted_idx) {
    vector<BidirectedNode *> ret;
    ret.reserve(frogs.size());
    ret.push_back(new BidirectedNode(frogs[sorted_idx[0]]));
    
    for (int i = 1; i != frogs.size(); ++i) {
        BidirectedNode *back = ret.back();
        ret.push_back(back->insert_right(frogs[sorted_idx[i]]));
    }
    
    return ret;
}

inline int dist(int a, int b) {
    if (a < b) {
        return b - a;
    }
    return m - a + b;
}

int clean_path(Frog const &frog) {
    int cnt = 0;
    
    while (true) {
        BidirectedNode *next = frog.node->right;
        
        if (dist(frog.pos, next->frog.pos) > frog.jump ||
            next->frog.num == frog.num)
        {
            return cnt;
        }
        
        ++cnt;
        next->frog.alive = false;
        delete next;
    }
}

int main() {
    clock_t start = clock();
    
    int n;
    scanf("%d %d", &n, &m);
    
    vector<Frog> frogs(n);
    vector<int> curr(n), sorted_idx(n);
    
    for (int i = 0; i != n; ++i) {
        scanf("%d %d", &frogs[i].pos, &frogs[i].jump);
        --frogs[i].pos;
        frogs[i].num = i;
        curr[i] = i;
        sorted_idx[i] = i;
    }
    
    sort(sorted_idx.begin(),
         sorted_idx.end(),
         [&](int a, int b){ return frogs[a].pos < frogs[b].pos; });
    vector<BidirectedNode *> list = build_list(frogs, sorted_idx);
    
    int iter_num = 0;
    vector<int> next;
    
    while (true) {
        bool to_next = false;
        
        for (int i = 0; i != (int)curr.size(); ++i) {
            Frog &frog = frogs[curr[i]];
            
            if (!frog.alive) {
                if (!to_next) {
                    next.insert(next.begin(), curr.begin(), curr.begin() + i);
                    to_next = true;
                }
                continue;
            } else if (to_next) {
                next.push_back(curr[i]);
            }
            
            int killed = clean_path(frog);
            frog.pos = (frog.pos + frog.jump) % m;
            frog.jump = max(frog.jump - killed, 0);
        }
        
        if (!next.empty()) {
            curr.swap(next);
            next.clear();
        }
        
        if (iter_num == 10000) {
            if ((double)(clock() - start) / CLOCKS_PER_SEC > 1.9) {
                break;
            }
            iter_num = 0;
        }
        ++iter_num;
    }
    
    printf("%d\n", (int)curr.size());
    for (int i = 0; i != curr.size(); ++i) {
        printf("%d ", curr[i] + 1);
        // delete frogs[curr[i]].node;
    }
    
    return 0;
}
