#include <algorithm>
#include <cassert>
#include <iostream>
#include <set>
#include <vector>

using namespace std;

typedef long long ll;

ll const INF = 1e18;
ll m;

inline ll div_ceil(ll a, ll b) {
    return (a + b - 1) / b;
}

struct Frog {
    int num;
    Frog *prev_frog, *next_frog;
    ll pos, jump, time;
    bool alive;
    
    Frog() : alive(true), time(0) {}
    
    void update(ll new_time) {
        pos = (pos + jump * (new_time - time)) % m;
        time = new_time;
    }
    
    ll rel_pos(ll new_time) const {
        return (pos + jump * (new_time - time)) % m;
    }
    
    ll dist(ll a, ll b) const {
        return (b > a ? b - a : m - a + b);
    }
    
    ll event() const {
        ll first_time = max(time, next_frog->time - (num < next_frog->num ? 0 : 1));
        ll second_time = max(next_frog->time, time + (num < next_frog->num ? 0 : 1));
        
        ll first_pos = rel_pos(first_time);
        ll second_pos = next_frog->rel_pos(second_time);
        
        if (num == next_frog->num) {
            return INF;
        }
        if (dist(first_pos, second_pos) <= jump) {
            return first_time + 1;
        }
        if (jump <= next_frog->jump) {
            return INF;
        }
        return first_time + 1 + div_ceil(dist((first_pos + jump) % m, second_pos), (jump - next_frog->jump));
    }
    
    bool operator<(Frog const &f) const {
        return pos < f.pos;
    }
};

int main() {
    int n;
    cin >> n >> m;
    
    int alive = n;
    vector<Frog> frogs(n);
    
    for (int i = 0; i != n; ++i) {
        cin >> frogs[i].pos >> frogs[i].jump;
        --frogs[i].pos;
        frogs[i].num = i;
    }
    
    sort(frogs.begin(), frogs.end());
    for (int i = 0; i != n; ++i) {
        frogs[i].next_frog = &frogs[(i + 1) % n];
        frogs[(i + 1) % n].prev_frog = &frogs[i];
    }

    
    while (true) {
        ll time = INF;
        Frog *frog;
        
        for (int i = 0; i != n; ++i) {
            if (frogs[i].alive) {
                ll curr_time = frogs[i].event();
                
                if (curr_time == INF) continue;
                if (curr_time < time || (curr_time == time && frog->num > frogs[i].num)) {
                    time = curr_time;
                    frog = &frogs[i];
                }
            }
        }
        
        if (time == INF) {
            break;
        }
        
        int killed = 0;
        while (frog->event() == time) {
            frog->next_frog->alive = false;
            frog->next_frog = frog->next_frog->next_frog;
            frog->next_frog->prev_frog = frog;
            ++killed;
        }
        
        assert(killed);
        frog->update(time);
        frog->jump = max(frog->jump - killed, 0LL);
        
        alive -= killed;
    }
    
    cout << alive << '\n';
    for (int i = 0; i != n; ++i) {
        if (frogs[i].alive) {
            cout << frogs[i].num + 1 << ' ';
        }
    }
    
    return 0;
}
