#include <algorithm>
#include <cassert>
#include <iostream>
#include <set>
#include <vector>

using namespace std;

typedef long long ll;

ll const INF = 1e18;
ll m;

inline ll div_ceil(ll a, ll b) {
    return (a + b - 1) / b;
}

struct Frog {
    int num;
    ll pos, jump, time;
    bool alive;
    
    Frog() : alive(true), time(0) {}
    
    void update(ll new_time) {
        pos = (pos + jump * (new_time - time)) % m;
        time = new_time;
    }
    
    ll rel_pos(ll new_time) const {
        return (pos + jump * (new_time - time)) % m;
    }
    
    ll dist(ll a, ll b) const {
        return (b > a ? b - a : m - a + b);
    }
    
    ll event(Frog const &frog) const {
        ll first_time = max(time, frog.time - (num < frog.num ? 0 : 1));
        ll second_time = max(frog.time, time + (num < frog.num ? 0 : 1));
        
        ll first_pos = rel_pos(first_time);
        ll second_pos = frog.rel_pos(second_time);
        
        if (num == frog.num) {
            return INF;
        }
        if (dist(first_pos, second_pos) <= jump) {
            return first_time + 1;
        }
        if (jump <= frog.jump) {
            return INF;
        }
        return first_time + 1 + div_ceil(dist((first_pos + jump) % m, second_pos), (jump - frog.jump));
    }
    
    bool operator<(Frog const &f) const {
        return pos < f.pos;
    }
};

ll get_next(std::vector<Frog> &frogs, Frog **from, Frog **to) {
    ll ret = INF;
    
    for (int i = 0; i != frogs.size(); ++i) {
        if (!frogs[i].alive) continue;
        for (int j = 0; j != frogs.size(); ++j) {
            if (!frogs[j].alive) continue;
            
            ll curr_time = frogs[i].event(frogs[j]);
            if (curr_time == INF) {
                continue;
            }
            if (curr_time < ret || (curr_time == ret && frogs[i].num < (*from)->num)) {
                *from = &frogs[i];
                *to = &frogs[j];
                ret = curr_time;
            }
        }
    }
    
    return ret;
}

int main() {
    int n;
    cin >> n >> m;
    
    int alive = n;
    vector<Frog> frogs(n);
    
    for (int i = 0; i != n; ++i) {
        cin >> frogs[i].pos >> frogs[i].jump;
        --frogs[i].pos;
        frogs[i].num = i;
    }
    
    int last_killed = 0;
    while (true) {
        Frog *from, *to;
        ll time = get_next(frogs, &from, &to);
        
        if (time == INF) {
            break;
        }
        
        to->alive = false;
        ++last_killed;
        --alive;
        
        Frog *next_from, *next_to;
        if (get_next(frogs, &next_from, &next_to) != time || from != next_from) {
            from->jump = max(from->jump - last_killed, 0LL);
            last_killed = 0;
        }
    }
    
    cout << alive << '\n';
    for (int i = 0; i != n; ++i) {
        if (frogs[i].alive) {
            cout << frogs[i].num + 1 << ' ';
        }
    }
    
    return 0;
}
