#include <algorithm>
#include <cassert>
#include <iostream>
#include <set>
#include <vector>

using namespace std;

typedef long long ll;

ll const INF = 1e18;
ll m;

inline ll div_ceil(ll a, ll b) {
    return (a + b - 1) / b;
}

struct Frog {
    int num;
    Frog *prev_frog, *next_frog;
    ll pos, jump, time, next_event;
    bool alive;
    
    Frog() : alive(true), time(0) {}
    
    void update(ll new_time) {
        pos = (pos + jump * (new_time - time)) % m;
        time = new_time;
    }
    
    ll rel_pos(ll new_time) const {
        return (pos + jump * (new_time - time)) % m;
    }
    
    ll dist(ll a, ll b) const {
        return (b > a ? b - a : m - a + b);
    }
    
    ll event() {
        ll first_time = max(time, next_frog->time - (num < next_frog->num ? 0 : 1));
        ll second_time = max(next_frog->time, time + (num < next_frog->num ? 0 : 1));
        
        ll first_pos = rel_pos(first_time);
        ll second_pos = next_frog->rel_pos(second_time);
        
        if (num == next_frog->num) {
            next_event = INF;
        } else if (dist(first_pos, second_pos) < jump) {
            return next_event = first_time + 1;
        } else if (jump <= next_frog->jump) {
            return next_event = INF;
        } else {
            next_event = first_time + 1 + div_ceil(dist((first_pos + jump) % m, second_pos), (jump - next_frog->jump));
        }
        
        return next_event;
    }
    
    bool operator<(Frog const &f) const {
        return pos < f.pos;
    }
};

struct Event {
    ll time;
    Frog &frog;
    
    Event(ll time, Frog &frog) : time(time), frog(frog) {}
    
    bool operator<(Event const &e) const {
        if (time == e.time) {
            return frog.num < e.frog.num;
        }
        return time < e.time;
    }
};


int main() {
    int n;
    cin >> n >> m;
    
    int alive = n;
    vector<Frog> frogs(n);
    
    for (int i = 0; i != n; ++i) {
        cin >> frogs[i].pos >> frogs[i].jump;
        --frogs[i].pos;
        frogs[i].num = i;
    }
    
    set<Event> events;
    
    sort(frogs.begin(), frogs.end());
    for (int i = 0; i != n; ++i) {
        frogs[i].next_frog = &frogs[(i + 1) % n];
        frogs[(i + 1) % n].prev_frog = &frogs[i];
        
        events.insert(Event(frogs[i].event(), frogs[i]));
    }
    
    while (events.begin()->time != INF) {
        set<Event>::const_iterator begin = events.begin();
        ll time = begin->time;
        Frog &frog = begin->frog;
        
        events.erase(begin);
        
        int killed = 0;
        while (frog.event() == time) {
            frog.next_frog->alive = false;
            events.erase(Event(frog.next_frog->next_event, *frog.next_frog));
            frog.next_frog = frog.next_frog->next_frog;
            frog.next_frog->prev_frog = &frog;
            ++killed;
        }
        
        assert(killed);
        frog.update(time);
        frog.jump = max(frog.jump - killed, 0LL);
        
        events.erase(Event(frog.prev_frog->next_event, *frog.prev_frog));
        events.insert(Event(frog.prev_frog->event(), *frog.prev_frog));
        events.insert(Event(frog.event(), frog));
        
        alive -= killed;
    }
    
    cout << alive << '\n';
    for (int i = 0; i != n; ++i) {
        if (frogs[i].alive) {
            cout << frogs[i].num + 1 << ' ';
        }
    }
    
    return 0;
}
