#include <algorithm>
#include <cstdio>
#include <ctime>
#include <set>
#include <vector>

using namespace std;

struct Frog {
    int num, pos, jump;
    bool alive;
    
    Frog() : alive(true) {}
};

class SegmentTree {
    // get left_non_zero on segment
    
    int sz;
    vector<int> tree;
    
    void set(int n, int L, int R, int l, int r, int val) {
        if (L >= r || l >= R) {
            return;
        }
        
        if (L + 1 == R) {
            tree[n] = val;
            return;
        }
        
        int middle = (L + R) / 2;
        set(n * 2 + 1, L, middle, l, r, val);
        set(n * 2 + 2, middle, R, l, r, val);
        
        if (tree[2 * n + 1]) {
            tree[n] = tree[2 * n + 1];
        } else {
            tree[n] = tree[2 * n + 2];
        }
    }
    
    int get(int n, int L, int R, int l, int r) {
        if (L >= r || l >= R) {
            return 0;
        }
        
        if (L >= l && R <= r) {
            return tree[n];
        }
        
        int middle = (L + R) / 2;
        int left = get(n * 2 + 1, L, middle, l, r);
        if (left) return left;
        return get(n * 2 + 2, middle, R, l, r);
    }
    
    static int norm(int n) {
        int res = 1;
        while (res < n) res *= 2;
        return res;
    }
    
public:
    SegmentTree(int n) : sz(norm(n)), tree(2 * sz, 0) {}
    
    void set(int pos, int val) {
        set(0, 0, sz, pos, pos + 1, val);
    }
    
    int get(int left, int right) {
        return get(0, 0, sz, left, right);
    }
};

int clean_path(int const num, int left, int right, SegmentTree &tree, vector<Frog> &frogs) {
    int pos, cnt = 0;
    
    while ((pos = tree.get(left, right + 1))) {
        if (pos == num + 1) {
            break;
        }
        
        --pos;
        ++cnt;
        
        frogs[pos].alive = false;
        tree.set(frogs[pos].pos, 0);
        left = frogs[pos].pos + 1;
    }
    
    return cnt;
}

int main() {
    clock_t start = clock();
    
    int n, m;
    scanf("%d %d", &n, &m);
    
    SegmentTree tree(m);
    vector<Frog> frogs(n);
    vector<int> curr(n);
    
    for (int i = 0; i != n; ++i) {
        scanf("%d %d", &frogs[i].pos, &frogs[i].jump);
        --frogs[i].pos;
        
        curr[i] = i;
        frogs[i].num = i;
        tree.set(frogs[i].pos, i + 1);
    }
    
    int iter_num = 0;
    vector<int> next;
    
    while (true) {
        bool to_next = false;
        
        for (int i = 0; i != (int)curr.size(); ++i) {
            Frog &frog = frogs[curr[i]];
            
            if (!frog.alive) {
                if (!to_next) {
                    next.insert(next.begin(), curr.begin(), curr.begin() + i);
                    to_next = true;
                }
                continue;
            } else if (to_next) {
                next.push_back(curr[i]);
            }
            
            if (!frog.jump) continue;
            int finish = (frog.pos + frog.jump) % m, killed;
            
            if (finish > frog.pos) {
                killed = clean_path(curr[i], frog.pos + 1, finish, tree, frogs);
            } else {
                killed = clean_path(curr[i], frog.pos + 1, m - 1, tree, frogs);
                killed += clean_path(curr[i], 0, finish, tree, frogs);
            }
            
            tree.set(frog.pos, 0);
            frog.pos = finish;
            tree.set(frog.pos, curr[i] + 1);
            frog.jump = max(frog.jump - killed, 0);
        }
        
        if (!next.empty()) {
            curr.swap(next);
            next.clear();
        }
        
        if (iter_num == 10000) {
            if ((double)(clock() - start) / CLOCKS_PER_SEC > 1.9) {
                break;
            }
            iter_num = 0;
        }
        ++iter_num;
    }
    
    printf("%d\n", (int)curr.size());
    for (int i = 0; i != curr.size(); ++i) {
        printf("%d ", curr[i] + 1);
    }
    
    return 0;
}
