#include "testlib.h"
#include <vector>
#include <algorithm>
#include <utility>
#include <bitset>

using namespace std;

const int MAXN = 1000;

template <typename Iter>
bool _is_sorted(Iter begin, Iter end) {
    for (Iter it = begin; it != end - 1; ++it) {
        if (!(*it < *(it + 1))) {
            return false;
        }
    }
    return true;
}

int n, k;
long long validateAnswer(InStream& ans_stream, TResult wrong) {
    vector <int> currentLine(n);
    bitset<MAXN * MAXN + 1> used;
    
    long long kSum = ans_stream.readLong();
    
    long long actualSum = 0;
    
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            currentLine[j] = ans_stream.readInt(1, n * n);
            if (j == k - 1) {
                actualSum += currentLine[j];
            }
            if (used[currentLine[j]]) {
                quitf(wrong, "%d used twice\n", currentLine[j]);
            }
            used[currentLine[j]] = true;
        }
        if (!_is_sorted(currentLine.begin(), currentLine.end())) {
            quitf(wrong, "%d%s line not sorted", i, englishEnding(i).c_str());
        }
    }
    if (actualSum != kSum) {
        quitf(wrong, "Solution says sum is %lld, but it is %lld",
            kSum, actualSum);
    }
    return kSum;
}

int main(int argc, char **argv) {
    registerTestlibCmd(argc, argv);
    n = inf.readInt();
    k = inf.readInt();
    
    long long contestantKSum = validateAnswer(ouf, _wa);
    long long juryKSum = validateAnswer(ans, _fail);
    if (juryKSum != contestantKSum) {
        quitf((juryKSum < contestantKSum ? _fail : _wa), "contestant's answer is %lld, jury's -- %lld",
            contestantKSum, juryKSum);
    }
    quitf(_ok, "sum %lld", contestantKSum);
}
