# n is represented as a string
def find_symmetric_decomposition_length(n, summand_len):
    if (not len(n) - 1 <= summand_len <= len(n) or 
        summand_len == len(n) - 1 and n[0] != '1'):
        return ""
        
    left_carry_out, left_index = 0, 0
    if summand_len == len(n) - 1:
        left_carry_out, left_index = 1, 1
    right_carry_in, right_index = 0, len(n) - 1
    result_summand_greater = False
    
    result = [0] * summand_len
    result_left_index, result_right_index = 0, summand_len - 1
    while left_index < right_index:            
        left_digit = int(n[left_index])
        right_digit = int(n[right_index])
        
        # only three valid cases are possible
        if (left_digit == 0 and left_carry_out == 1 and            
            right_digit == 9 and right_carry_in == 0):
            # right_carry_out != left_carry_out, case 1
            digits_sum = 9            
            left_carry_in, right_carry_out = 1, 0
        elif (left_digit == 9 and left_carry_out == 0 and
              right_digit == 0 and right_carry_in == 1):
            # right_carry_out != left_carry_out, symmetrical case
            digits_sum = 9            
            left_carry_in, right_carry_out = 0, 1
        else:
            # right_carry_out == left_carry_out
            right_carry_out = left_carry_out            
            digits_sum = right_digit + 10 * right_carry_out - right_carry_in
            if not 0 <= digits_sum <= 18:
                # < 0 iff right_digit == 0, right_carry_out == 0, right_carry_in == 1
                # > 18 iff right_digit == 9, right_carry_out == 1, right_carry_in == 0
                return ""        
            
            left_carry_in = left_digit - right_digit + right_carry_in
            if not 0 <= left_carry_in <= 1:
                # impossible combination of left_digit, right_digit, right_carry_in
                return ""
        
        # distributing the sum of digits
        if result_summand_greater:
            # maximizing another summand
            if digits_sum >= 9:
                result[result_left_index], result[result_right_index] = digits_sum - 9, 9
            else:
                result[result_left_index], result[result_right_index] = 0, digits_sum
        else:
            # digits as close as possible
            result[result_right_index] = digits_sum // 2
            result[result_left_index] = digits_sum - result[result_right_index]
            if result[result_left_index] > result[result_right_index]:
                result_summand_greater = True
                            
        # moving to the next iteration
        left_carry_out, right_carry_in = left_carry_in, right_carry_out                            
        left_index, right_index = left_index + 1, right_index - 1
        result_left_index, result_right_index = result_left_index + 1, result_right_index - 1
    
    if left_index == right_index:
        # odd summand_len
        digit = int(n[left_index])
        digits_sum = digit + left_carry_out * 10 - right_carry_in
        if not 0 <= digits_sum <= 18 or digits_sum % 2 != 0:
            return ""
        result[result_left_index] = digits_sum // 2
    else:
        # even summand_len
        if left_carry_out != right_carry_in:
            return ""
    
    result = ''.join(map(str, result))
    if result[0] == '0':
        # the leading zero is prohibited
        return ""
    else:
        return result


def find_symmetric_decomposition(n):
    answer = find_symmetric_decomposition_length(n, len(n) - 1)
    if answer == "":
        answer = find_symmetric_decomposition_length(n, len(n))
    return ("0" if answer == "" else answer)
    
print(find_symmetric_decomposition(input()))
