def find_summand(n, summand_len, carries_half):
    result = [0] * summand_len
    result_left_index, result_right_index = 0, summand_len - 1
    carry = 0
    n_index = len(n) - 1
    result_summand_greater = False
    
    for i in range(len(carries_half) - 1, -1, -1):
        sum_total = n[n_index] + int(carries_half[i]) * 10
        digits_sum = sum_total - carry
        if not 0 <= digits_sum <= 18:
            return "0"
        carry = (1 if sum_total >= 10 else 0)
        
        if result_left_index == result_right_index:
            # we are in the middle
            if digits_sum % 2 != 0:
                return "0"
            result[result_left_index] = digits_sum // 2
        else:        
            # distributing the sum of digits
            if result_summand_greater:
                # maximizing another summand
                if digits_sum >= 9:
                    result[result_left_index], result[result_right_index] = digits_sum - 9, 9
                else:
                    result[result_left_index], result[result_right_index] = 0, digits_sum
            else:
                # digits as close as possible
                result[result_right_index] = digits_sum // 2
                result[result_left_index] = digits_sum - result[result_right_index]
                if result[result_left_index] > result[result_right_index]:
                    result_summand_greater = True
            
        n_index -= 1
        result_right_index -= 1
        result_left_index += 1
    
    if result[0] == 0:
        # the leading zero is prohibited
        return "0"
    
    # check the sum
    while result_right_index >= 0:
        sum_total = result[result_right_index] + result[result_left_index] + carry
        carry = 0
        digit = sum_total
        if sum_total >= 10:
            carry = 1
            digit -= 10
        
        if n[n_index] != digit:
            return "0"        
        
        result_right_index -= 1
        result_left_index += 1
        n_index -= 1
        
    if (carry == 1 and (n_index != 0 or n[n_index] != 1)) or (carry == 0 and n_index >= 0):
        return "0"
    
    return ''.join(map(str, result))

def find_symmetric_decomposition_brute_force_half_carries(n, summand_len):
    n_list = list(map(int, list(n)))
    n_int = int(n)
    if summand_len == 0 or n_int <= 10 ** (summand_len - 1):
        return ""
    
    best_difference = n_int
    result = -1
    half_size_up = (summand_len + 1) // 2
    half_size_down = summand_len // 2
    for carries_half in range(2 ** half_size_up):
        summand = find_summand(n_list, summand_len, bin(carries_half)[2:].zfill(half_size_up))
        if summand == "0":
            continue
        summand_reverse = summand[::-1]
        
        summand = int(summand)
        summand_reverse = int(summand_reverse)
        if summand + summand_reverse == n_int:
            max_summand = max(summand, summand_reverse)
            min_summand = min(summand, summand_reverse)
            if (max_summand - min_summand < best_difference):
                best_difference = max_summand - min_summand
                result = max_summand
    return str(result) if result != -1 else ""

def find_symmetric_decomposition(n):
    answer2 = find_symmetric_decomposition_brute_force_half_carries(n, len(n))
    answer1 = find_symmetric_decomposition_brute_force_half_carries(n, len(n) - 1)    
    if answer1 == "" and answer2 == "":
        return "0"
    
    diff1 = int(n)
    diff2 = int(n)
    if answer1 != "":
        diff1 = int(answer1) - int(answer1[::-1])
    if answer2 != "":
        diff2 = int(answer2) - int(answer2[::-1])
    return answer1 if diff1 < diff2 else answer2
    
print(find_symmetric_decomposition(input()))
