def optimal_summand(digit_sums):
    result_summand_greater = False
    result = [0] * len(digit_sums)
    result_left_index, result_right_index = 0, len(result) - 1
    while result_left_index < result_right_index:
        digits_sum = digit_sums[result_left_index]
        if result_summand_greater:
            # maximizing another summand
            if digits_sum >= 9:
                result[result_left_index], result[result_right_index] = digits_sum - 9, 9
            else:
                result[result_left_index], result[result_right_index] = 0, digits_sum
        else:
            # digits as close as possible
            result[result_right_index] = digits_sum // 2
            result[result_left_index] = digits_sum - result[result_right_index]
            if result[result_left_index] > result[result_right_index]:
                result_summand_greater = True
        result_left_index, result_right_index = result_left_index + 1, result_right_index - 1
    
    if result_left_index == result_right_index:
        result[result_left_index] = digit_sums[result_left_index] // 2
        
    result = ''.join(map(str, result))
    if result[0] == '0':
        # the leading zero is prohibited
        return ""
    else:
        return result

def get_decomposition(n, summand_len, left_carry_in, right_carry_out):
    if summand_len == 0:
        return ""
    
    result = [0] * summand_len
    if summand_len % 2 == 1:
        left_index, right_index = summand_len // 2, summand_len // 2
        if summand_len < len(n):
            digit = int(n[left_index + 1])
        else:
            digit = int(n[left_index])
            
        s = digit + 10 * left_carry_in - right_carry_out
        if s % 2 != 0:
            return ""
        result[left_index] = s        
        left_index, right_index = left_index - 1, right_index + 1
    else:
        if left_carry_in != right_carry_out:
            return ""
        left_index, right_index = summand_len // 2 - 1, summand_len // 2
        
    while right_index < summand_len:        
        if summand_len < len(n):
            left_digit = int(n[left_index + 1])
            right_digit = int(n[right_index + 1])            
        else:
            left_digit = int(n[left_index])
            right_digit = int(n[right_index])        
        
        # only three valid cases are possible
        if (left_digit == 9 and right_carry_out == 1 and            
            right_digit == 0 and left_carry_in == 0):
            # right_carry_out != left_carry_out, case 1
            digits_sum = 9            
            right_carry_in, left_carry_out = 1, 0
        elif (left_digit == 0 and right_carry_out == 0 and
            right_digit == 9 and left_carry_in == 1):
            # right_carry_out != left_carry_out, symmetrical case
            digits_sum = 9            
            right_carry_in, left_carry_out = 0, 1
        else:
            # right_carry_out == left_carry_out
            left_carry_out = right_carry_out
            digits_sum = left_digit + 10 * left_carry_out - left_carry_in
            #if not 0 <= digits_sum <= 18:
                # < 0 iff right_digit == 0, right_carry_out == 0, right_carry_in == 1
                # > 18 iff right_digit == 9, right_carry_out == 1, right_carry_in == 0
            #    return ""        
                    
            right_carry_in = right_digit - left_digit + left_carry_in
            #if not 0 <= right_carry_in <= 1:
                # impossible combination of left_digit, right_digit, right_carry_in
            #    return ""
        result[left_index] = digits_sum
        result[right_index] = digits_sum
        
        left_index, right_index = left_index - 1, right_index + 1
        left_carry_in, right_carry_out = left_carry_out, right_carry_in
        
    if summand_len < len(n):
        if left_carry_in != 1 or int(n[0]) != 1:
            return ""
    
    if summand_len == len(n) and left_carry_in != 0:
        return ""
    
    if right_carry_out != 0:
        return ""
    
    return optimal_summand(result)

def find_symmetric_decomposition(n):
    for left_carry_in in range(2):
        for right_carry_out in range(2):
            answer = get_decomposition(n, len(n) - 1, left_carry_in, right_carry_out)
            if answer != "":
                return answer
    
    for left_carry_in in range(2):
        for right_carry_out in range(2):                
            answer = get_decomposition(n, len(n), left_carry_in, right_carry_out)
            if answer != "":
                return answer                
            
    return "0"

print(find_symmetric_decomposition(input()))
